@@ -1,6 +1,6 @@
 /*
 
-   Copyright 2022, dettus@dettus.net
+   Copyright 2023, dettus@dettus.net
 
    Redistribution and use in source and binary forms, with or without modification,
    are permitted provided that the following conditions are met:
@@ -782,7 +782,7 @@ int loader_appleii(char *appleiiname,
 		}
 		if (gameid==-1 || gameid==newgameid) gameid=newgameid;
 		else {
-			fprintf(stderr,"Game detection ambigous\n");
+			fprintf(stderr,"Game detection ambiguous\n");
 			return -1;
 		}
 		if (disknum>=0 && disknum<MAXDISKS)
