@@ -1,6 +1,6 @@
 /*
 
-Copyright 2022, dettus@dettus.net
+Copyright 2023, dettus@dettus.net
 
 Redistribution and use in source and binary forms, with or without modification,
 are permitted provided that the following conditions are met:
@@ -27,9 +27,25 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #ifndef	MAGGFXLOADER_H
 #define	MAGGFXLOADER_H
-int loader_init(int argc,char** argv,FILE *f_inifile,
-	char *magbuf,int* magsize,
-	char* gfxbuf,int* gfxsize);
 
+#define	MAXFILENAMESIZE	1024
+typedef	enum _eBinType
+{
+	BINTYPE_NONE,
+	BINTYPE_MAGGFX,
+	BINTYPE_MSDOS,
+	BINTYPE_TWORSC,
+	BINTYPE_D64,
+	BINTYPE_AMSTRADCPC,
+	BINTYPE_SPECTRUM,
+	BINTYPE_ARCHIMEDES,
+	BINTYPE_ATARIXL,
+	BINTYPE_APPLEII
+} eBinType;
+
+int maggfxloader(char *magbuf,int* magsize,
+	char* gfxbuf,int* gfxsize,
+	int nodoc,
+	eBinType binType,char* magfilename,char* gfxfilename,char* binfilename);
 #endif
 
